@@ -246,9 +246,10 @@ Kid3Cli::Kid3Cli(Kid3Application* app,
                  AbstractCliIO* io, QObject* parent) :
   AbstractCli(io, parent),
   m_app(app),
-  m_tagMask(TrackData::TagV2V1), m_fileNameChanged(false)
+  m_tagMask(TrackData::TagV2V1), m_timeoutMs(0), m_fileNameChanged(false)
 {
   m_cmds << new HelpCommand(this)
+         << new TimeoutCommand(this)
          << new QuitCommand(this)
          << new CdCommand(this)
          << new PwdCommand(this)
