@@ -6,7 +6,7 @@
  * \author Urs Fleisch
  * \date 9 Jan 2003
  *
- * Copyright (C) 2003-2013  Urs Fleisch
+ * Copyright (C) 2003-2014  Urs Fleisch
  *
  * This file is part of Kid3.
  *
@@ -40,22 +40,25 @@
 #include "config.h"
 #include "qtcompatmac.h"
 #include "kid3form.h"
+#include "filelist.h"
 #include "kid3application.h"
 #include "kdeconfigdialog.h"
 #include "guiconfig.h"
 #include "tagconfig.h"
 #include "serverimporter.h"
 #include "servertrackimporter.h"
-#include "kdeplatformtools.h"
 
 /**
  * Constructor.
  *
+ * @param platformTools platform specific tools
+ * @param app application context
  * @param parent parent widget
  */
-KdeMainWindow::KdeMainWindow(QWidget* parent) :
+KdeMainWindow::KdeMainWindow(IPlatformTools* platformTools,
+                             Kid3Application* app, QWidget* parent) :
   KXmlGuiWindow(parent),
-  BaseMainWindow(this, m_platformTools = new KdePlatformTools),
+  BaseMainWindow(this, platformTools, app),
   m_fileOpenRecent(0), m_viewToolBar(0), m_viewStatusBar(0),
   m_settingsAutoHideTags(0), m_settingsShowHidePicture(0)
 {
@@ -67,7 +70,6 @@ KdeMainWindow::KdeMainWindow(QWidget* parent) :
  */
 KdeMainWindow::~KdeMainWindow()
 {
-  delete m_platformTools;
 }
 
 /** Only defined for generation of translation files */
@@ -94,6 +96,10 @@ void KdeMainWindow::initActions()
       form(), SLOT(selectAllFiles()), actionCollection());
   KAction* editDeselect = KStandardAction::deselect(
       form(), SLOT(deselectAllFiles()), actionCollection());
+  KAction* editFind = KStandardAction::find(
+      impl(), SLOT(find()), actionCollection());
+  KAction* editReplace = KStandardAction::replace(
+      impl(), SLOT(findReplace()), actionCollection());
   setStandardToolBarMenuEnabled(true);
   createStandardStatusBarAction();
   KAction* settingsShortcuts = KStandardAction::keyBindings(
@@ -107,11 +113,14 @@ void KdeMainWindow::initActions()
   m_fileOpenRecent->setStatusTip(tr("Opens a recently used directory"));
   fileRevert->setStatusTip(
       tr("Reverts the changes of all or the selected files"));
+  fileRevert->setShortcut(KStandardShortcut::shortcut(KStandardShortcut::Undo));
   fileSave->setStatusTip(tr("Saves the changed files"));
   fileQuit->setStatusTip(tr("Quits the application"));
   editSelectAll->setStatusTip(tr("Select all files"));
   editSelectAll->setShortcut(KShortcut(QLatin1String("Alt+Shift+A")));
   editDeselect->setStatusTip(tr("Deselect all files"));
+  editFind->setStatusTip(tr("Find"));
+  editReplace->setStatusTip(tr("Find and replace"));
   settingsShortcuts->setStatusTip(tr("Configure Shortcuts"));
   settingsToolbars->setStatusTip(tr("Configure Toolbars"));
   settingsConfigure->setStatusTip(tr("Preferences dialog"));
@@ -279,6 +288,18 @@ void KdeMainWindow::initActions()
   KAction* actionFileListFocus = new KAction(tr("File List") + QLatin1String(": ") + tr("Focus"), this);
   actionCollection()->addAction(QLatin1String("filelist_focus"), actionFileListFocus);
   connect(actionFileListFocus, SIGNAL(triggered()), form(), SLOT(setFocusFileList()));
+  KAction* actionFileListRename = new KAction(tr("&Rename"), this);
+  actionFileListRename->setShortcut(QKeySequence(Qt::Key_F2));
+  actionFileListRename->setShortcutContext(Qt::WidgetShortcut);
+  connect(actionFileListRename, SIGNAL(triggered()), impl(), SLOT(renameFile()));
+  actionCollection()->addAction(QLatin1String("filelist_rename"), actionFileListRename);
+  form()->getFileList()->setRenameAction(actionFileListRename);
+  KAction* actionFileListDelete = new KAction(tr("&Move to Trash"), this);
+  actionFileListDelete->setShortcut(QKeySequence::Delete);
+  actionFileListDelete->setShortcutContext(Qt::WidgetShortcut);
+  connect(actionFileListDelete, SIGNAL(triggered()), impl(), SLOT(deleteFile()));
+  actionCollection()->addAction(QLatin1String("filelist_delete"), actionFileListDelete);
+  form()->getFileList()->setDeleteAction(actionFileListDelete);
   KAction* actionDirListFocus = new KAction(tr("Directory List") + QLatin1String(": ") + tr("Focus"), this);
   actionCollection()->addAction(QLatin1String("dirlist_focus"), actionDirListFocus);
   connect(actionDirListFocus, SIGNAL(triggered()), form(), SLOT(setFocusDirList()));
