@@ -252,7 +252,13 @@ void Kid3MainWindow::initActions()
   QAction* fileCreatePlaylist = new QAction(this);
   fileCreatePlaylist->setStatusTip(tr("Create M3U Playlist"));
   fileCreatePlaylist->setText(tr("&Create Playlist..."));
+#if QT_VERSION >= 0x040600
+  fileCreatePlaylist->setIcon(
+        QIcon::fromTheme(QLatin1String("format-justify-fill"),
+            QIcon(QLatin1String(":/images/view-media-playlist.png"))));
+#else
   fileCreatePlaylist->setIcon(QIcon(QLatin1String(":/images/view-media-playlist.png")));
+#endif
   fileCreatePlaylist->setObjectName(QLatin1String("create_playlist"));
   m_shortcutsModel->registerAction(fileCreatePlaylist, menuTitle);
   connect(fileCreatePlaylist, SIGNAL(triggered()),
@@ -266,6 +272,9 @@ void Kid3MainWindow::initActions()
   fileQuit->setText(tr("&Quit"));
   fileQuit->setShortcut(Qt::CTRL + Qt::Key_Q);
   fileQuit->setIcon(QCM_QIcon_fromTheme("application-exit"));
+#if QT_VERSION >= 0x040200
+  fileQuit->setMenuRole(QAction::QuitRole);
+#endif
   fileQuit->setObjectName(QLatin1String("file_quit"));
   m_shortcutsModel->registerAction(fileQuit, menuTitle);
   connect(fileQuit, SIGNAL(triggered()),
@@ -492,6 +501,9 @@ void Kid3MainWindow::initActions()
   settingsConfigure->setIcon(QCM_QIcon_fromTheme("preferences-system"));
 #if QT_VERSION >= 0x040600
   settingsConfigure->setShortcut(QKeySequence::Preferences);
+#endif
+#if QT_VERSION >= 0x040200
+  settingsConfigure->setMenuRole(QAction::PreferencesRole);
 #endif
   settingsConfigure->setObjectName(QLatin1String("options_configure"));
   m_shortcutsModel->registerAction(settingsConfigure, menuTitle);
@@ -517,6 +529,10 @@ void Kid3MainWindow::initActions()
   QAction* helpAbout = new QAction(this);
   helpAbout->setStatusTip(tr("About Kid3"));
   helpAbout->setText(tr("&About Kid3"));
+  helpAbout->setIcon(QCM_QIcon_fromTheme("help-about"));
+#if QT_VERSION >= 0x040200
+  helpAbout->setMenuRole(QAction::AboutRole);
+#endif
   helpAbout->setObjectName(QLatin1String("help_about_app"));
   m_shortcutsModel->registerAction(helpAbout, menuTitle);
   connect(helpAbout, SIGNAL(triggered()),
@@ -526,6 +542,9 @@ void Kid3MainWindow::initActions()
   QAction* helpAboutQt = new QAction(this);
   helpAboutQt->setStatusTip(tr("About Qt"));
   helpAboutQt->setText(tr("About &Qt"));
+#if QT_VERSION >= 0x040200
+  helpAboutQt->setMenuRole(QAction::AboutQtRole);
+#endif
   helpAboutQt->setObjectName(QLatin1String("help_about_qt"));
   m_shortcutsModel->registerAction(helpAboutQt, menuTitle);
   connect(helpAboutQt, SIGNAL(triggered()),
@@ -756,10 +775,18 @@ void Kid3MainWindow::slotHelpHandbook()
  */
 void Kid3MainWindow::slotHelpAbout()
 {
-  QMessageBox::about(
+    QMessageBox::about(
     this, QLatin1String("Kid3"),
-    QLatin1String("Kid3 " VERSION
-    "\n(c) 2003-" RELEASE_YEAR " Urs Fleisch\nufleisch@users.sourceforge.net"));
+    QLatin1String("<big><b>Kid3 " VERSION
+    "</b></big><br/><br/>") +
+    tr("Audio Tag Editor") +
+    QLatin1String("<br/><br/>(c) 2003-" RELEASE_YEAR
+    " <a href=\"mailto:ufleisch@users.sourceforge.net\">Urs Fleisch</a>"
+    "<br/><br/>"
+    "<a href=\"http://kid3.sourceforge.net/\">http://kid3.sourceforge.net</a><br/>") +
+    tr("License") +
+    QLatin1String(": <a href=\"http://www.gnu.org/licenses/licenses.html#GPL\">"
+    "GNU General Public License</a><br/> "));
 }
 
 /**
