@@ -48,10 +48,10 @@ BatchImportConfig::BatchImportConfig() :
     QLatin1String("Cover Art") <<
     QLatin1String("Custom Profile");
   m_profileSources <<
-    QLatin1String("MusicBrainz Release:75:SAC;Discogs:75:SAC;Amazon:75:SAC;gnudb.org:75:S;TrackType.org:75:S") <<
+    QLatin1String("MusicBrainz Release:75:SAC;Discogs:75:SA;Amazon:75:SAC;gnudb.org:75:S;TrackType.org:75:S") <<
     QLatin1String("MusicBrainz Release:75:SAC") <<
-    QLatin1String("Discogs:75:SAC") <<
-    QLatin1String("Amazon:75:C;Discogs:75:C;MusicBrainz Release:75:C") <<
+    QLatin1String("Discogs:75:SA") <<
+    QLatin1String("Amazon:75:C;MusicBrainz Release:75:C") <<
     QLatin1String("");
 }
 
@@ -100,8 +100,8 @@ void BatchImportConfig::readFromConfig(ISettings* config)
 
   // KConfig seems to strip empty entries from the end of the string lists,
   // so we have to append them again.
-  unsigned numNames = names.size();
-  while (static_cast<unsigned>(sources.size()) < numNames)
+  const int numNames = names.size();
+  while (sources.size() < numNames)
     sources.append(QLatin1String(""));
   /* Use defaults if no configuration found */
   QStringList::const_iterator namesIt, sourcesIt;
