@@ -37,6 +37,7 @@ const char* const defaultCommentName = "COMMENT";
 const char* defaultPluginOrder[] = {
   "Id3libMetadata",
   "OggFlacMetadata",
+  "Mp4v2Metadata",
   "TaglibMetadata",
   0
 };
@@ -50,9 +51,6 @@ int TagConfig::s_index = -1;
  */
 TagConfig::TagConfig() :
   StoredConfig<TagConfig>(QLatin1String("Tags")),
-  m_markTruncations(true),
-  m_enableTotalNumberOfTracks(false),
-  m_genreNotNumeric(false),
   m_commentName(QString::fromLatin1(defaultCommentName)),
   m_pictureNameItem(VP_METADATA_BLOCK_PICTURE),
   m_id3v2Version(ID3v2_3_0),
@@ -60,8 +58,11 @@ TagConfig::TagConfig() :
   m_textEncoding(TE_ISO8859_1),
   m_quickAccessFrames(FrameCollection::DEFAULT_QUICK_ACCESS_FRAMES),
   m_trackNumberDigits(1),
+  m_taggedFileFeatures(0),
   m_onlyCustomGenres(false),
-  m_taggedFileFeatures(0)
+  m_markTruncations(true),
+  m_enableTotalNumberOfTracks(false),
+  m_genreNotNumeric(false)
 {
 }
 
@@ -87,7 +88,12 @@ void TagConfig::writeToConfig(ISettings* config) const
   config->setValue(QLatin1String("ID3v2Version"), QVariant(m_id3v2Version));
   config->setValue(QLatin1String("TextEncodingV1"), QVariant(m_textEncodingV1));
   config->setValue(QLatin1String("TextEncoding"), QVariant(m_textEncoding));
+#ifdef Q_OS_MAC
+  // Convince Mac OS X to store a 64-bit value.
+  config->setValue(QLatin1String("QuickAccessFrames"), QVariant(m_quickAccessFrames | (Q_UINT64_C(1) << 63)));
+#else
   config->setValue(QLatin1String("QuickAccessFrames"), QVariant(m_quickAccessFrames));
+#endif
   config->setValue(QLatin1String("TrackNumberDigits"), QVariant(m_trackNumberDigits));
   config->setValue(QLatin1String("OnlyCustomGenres"), QVariant(m_onlyCustomGenres));
   config->setValue(QLatin1String("PluginOrder"), QVariant(m_pluginOrder));
@@ -114,7 +120,10 @@ void TagConfig::readFromConfig(ISettings* config)
   m_textEncodingV1 = config->value(QLatin1String("TextEncodingV1"), QLatin1String("ISO-8859-1")).toString();
   m_textEncoding = config->value(QLatin1String("TextEncoding"), TE_ISO8859_1).toInt();
   m_quickAccessFrames = config->value(QLatin1String("QuickAccessFrames"),
-                                     FrameCollection::DEFAULT_QUICK_ACCESS_FRAMES).toUInt();
+                                     FrameCollection::DEFAULT_QUICK_ACCESS_FRAMES).toULongLong();
+#ifdef Q_OS_MAC
+  m_quickAccessFrames &= ~(Q_UINT64_C(1) << 63);
+#endif
   m_trackNumberDigits = config->value(QLatin1String("TrackNumberDigits"), 1).toInt();
   m_onlyCustomGenres = config->value(QLatin1String("OnlyCustomGenres"), m_onlyCustomGenres).toBool();
   m_pluginOrder = config->value(QLatin1String("PluginOrder"),
