@@ -27,10 +27,13 @@
 #include "frametablemodel.h"
 #include <QApplication>
 #include <QComboBox>
+#include <QLineEdit>
 #include "fileconfig.h"
 #include "tagconfig.h"
 #include "formatconfig.h"
 #include "genres.h"
+#include "tracknumbervalidator.h"
+#include "pictureframe.h"
 
 /**
  * Constructor.
@@ -110,9 +113,25 @@ QVariant FrameTableModel::data(const QModelIndex& index, int role) const
     return QVariant();
   FrameCollection::const_iterator it = frameAt(index.row());
   if (role == Qt::DisplayRole || role == Qt::EditRole) {
-    if (index.column() == CI_Enable)
-      return getDisplayName(it->getName());
-    else if (index.column() == CI_Value)
+    if (index.column() == CI_Enable) {
+      QString displayName = getDisplayName(it->getName());
+      if (it->getType() == Frame::FT_Picture &&
+          it->getValue() != Frame::differentRepresentation()) {
+        QVariant fieldValue = it->getFieldValue(Frame::Field::ID_PictureType);
+        if (fieldValue.isValid()) {
+          PictureFrame::PictureType pictureType =
+              static_cast<PictureFrame::PictureType>(fieldValue.toInt());
+          if (pictureType != PictureFrame::PT_Other) {
+            QString typeName = PictureFrame::getPictureTypeName(pictureType);
+            if (!typeName.isEmpty()) {
+              displayName += QLatin1String(": ");
+              displayName += typeName;
+            }
+          }
+        }
+      }
+      return displayName;
+    } else if (index.column() == CI_Value)
       return it->getValue();
   } else if (role == Qt::CheckStateRole && index.column() == CI_Enable) {
     return m_frameSelected.at(index.row()) ? Qt::Checked : Qt::Unchecked;
@@ -256,10 +275,12 @@ void FrameTableModel::insertFrame(const Frame& frame)
 bool FrameTableModel::removeRows(int row, int count,
                         const QModelIndex&)
 {
-  beginRemoveRows(QModelIndex(), row, row + count - 1);
-  m_frames.erase(frameAt(row), frameAt(row + count));
-  resizeFrameSelected();
-  endRemoveRows();
+  if (count > 0) {
+    beginRemoveRows(QModelIndex(), row, row + count - 1);
+    m_frames.erase(frameAt(row), frameAt(row + count));
+    resizeFrameSelected();
+    endRemoveRows();
+  }
   return true;
 }
 
@@ -420,10 +441,13 @@ FrameCollection FrameTableModel::getEnabledFrames() const
  */
 void FrameTableModel::clearFrames()
 {
-  beginRemoveRows(QModelIndex(), 0, m_frames.size() - 1);
-  m_frames.clear();
-  m_frameSelected.clear();
-  endRemoveRows();
+  const int numFrames = m_frames.size();
+  if (numFrames > 0) {
+    beginRemoveRows(QModelIndex(), 0, numFrames - 1);
+    m_frames.clear();
+    m_frameSelected.clear();
+    endRemoveRows();
+  }
 }
 
 /**
@@ -540,39 +564,48 @@ void FrameTableModel::resizeFrameSelected()
 
 /**
  * Constructor.
- * @param parent parent widget
+ * @param parent parent QTableView
  */
-FrameTableLineEdit::FrameTableLineEdit(QWidget* parent) :
-  QLineEdit(parent)
-{
-  setObjectName(QLatin1String("FrameTableLineEdit"));
-  connect(this, SIGNAL(textChanged(QString)),
-          this, SLOT(formatTextIfEnabled(QString)));
+FrameItemDelegate::FrameItemDelegate(QObject* parent) : QItemDelegate(parent),
+  m_trackNumberValidator(new TrackNumberValidator(this)),
+  m_dateTimeValidator(new QRegExpValidator(QRegExp(QLatin1String(
+    // This is a simplified regular expression from
+    // http://www.pelagodesign.com/blog/2009/05/20/iso-8601-date-validation-that-doesnt-suck/
+    // relaxed to allow appending any string after a slash, so that ISO 8601
+    // periods of time can by entered while still providing suffient validation.
+    "(\\d{4})(-((0[1-9]|1[0-2])(-([12]\\d|0[1-9]|3[01]))?)(T((([01]\\d|2[0-3])"
+    "(:[0-5]\\d)?|24:00))?(:[0-5]\\d([\\.,]\\d+)?)?"
+    "([zZ]|([\\+-])([01]\\d|2[0-3]):?([0-5]\\d)?)?)?(/.*)?)?"
+  )), this)) {
+  setObjectName(QLatin1String("FrameItemDelegate"));
 }
 
 /**
  * Destructor.
  */
-FrameTableLineEdit::~FrameTableLineEdit() {}
+FrameItemDelegate::~FrameItemDelegate()
+{
+}
 
 /**
  * Format text if enabled.
  * @param txt text to format and set in line edit
  */
-void FrameTableLineEdit::formatTextIfEnabled(const QString& txt)
+void FrameItemDelegate::formatTextIfEnabled(const QString& txt)
 {
-  if (TagFormatConfig::instance().m_formatWhileEditing) {
+  QLineEdit* le;
+  if (TagFormatConfig::instance().m_formatWhileEditing &&
+      (le = qobject_cast<QLineEdit*>(sender())) != 0) {
     QString str(txt);
     TagFormatConfig::instance().formatString(str);
     if (str != txt) {
-      int curPos = cursorPosition();
-      setText(str);
-      setCursorPosition(curPos);
+      int curPos = le->cursorPosition();
+      le->setText(str);
+      le->setCursorPosition(curPos);
     }
   }
 }
 
-
 /**
  * Create an editor to edit the cells contents.
  * @param parent parent widget
@@ -627,14 +660,35 @@ QWidget* FrameItemDelegate::createEditor(
         cb->addItems(customGenres);
       }
       return cb;
-    } else if (id3v1 &&
-               (type == Frame::FT_Comment || type == Frame::FT_Title ||
-                type == Frame::FT_Artist || type == Frame::FT_Album)) {
-      FrameTableLineEdit* e = new FrameTableLineEdit(parent);
-      e->setMaxLength(type == Frame::FT_Comment ? 28 : 30);
-      e->setFrame(false);
-      return e;
     }
+    QWidget* editor = QItemDelegate::createEditor(parent, option, index);
+    QLineEdit* lineEdit = qobject_cast<QLineEdit*>(editor);
+    if (id3v1 &&
+        (type == Frame::FT_Comment || type == Frame::FT_Title ||
+         type == Frame::FT_Artist || type == Frame::FT_Album)) {
+      if (lineEdit) {
+        if (TagFormatConfig::instance().m_formatWhileEditing) {
+          connect(lineEdit, SIGNAL(textChanged(QString)),
+                  this, SLOT(formatTextIfEnabled(QString)));
+        }
+        lineEdit->setMaxLength(type == Frame::FT_Comment ? 28 : 30);
+      }
+    } else {
+      if (lineEdit) {
+        if (TagFormatConfig::instance().m_formatWhileEditing) {
+          connect(lineEdit, SIGNAL(textChanged(QString)),
+                  this, SLOT(formatTextIfEnabled(QString)));
+        }
+        if (TagFormatConfig::instance().m_enableValidation) {
+          if (type == Frame::FT_Track || type == Frame::FT_Disc) {
+            lineEdit->setValidator(m_trackNumberValidator);
+          } else if (type == Frame::FT_Date || type == Frame::FT_OriginalDate) {
+            lineEdit->setValidator(m_dateTimeValidator);
+          }
+        }
+      }
+    }
+    return editor;
   }
   return QItemDelegate::createEditor(parent, option, index);
 }
