@@ -461,13 +461,6 @@ public:
    */
   void formatFramesIfEnabled(FrameCollection& frames) const;
 
-  /**
-   * Open directory or add pictures on drop.
-   *
-   * @param paths paths of directories or files in directory
-   */
-  void openDrop(const QStringList& paths);
-
   /**
    * Add picture on drop.
    *
@@ -593,6 +586,13 @@ public:
   static QObjectList loadPlugins();
 
 public slots:
+  /**
+   * Open directory or add pictures on drop.
+   *
+   * @param paths paths of directories or files in directory
+   */
+  void openDrop(const QStringList& paths);
+
   /**
    * Revert file modifications.
    * Acts on selected files or all files if no file is selected.
@@ -914,6 +914,11 @@ public slots:
    */
   void applyFilter(const QString& expression);
 
+  /**
+   * Abort expression file filter.
+   */
+  void abortFilter();
+
   /**
    * Perform a batch import for the selected directories.
    * @param profile batch import profile
