@@ -287,12 +287,20 @@ bool ScriptInterface::expandDirectory()
 {
   QModelIndex index(m_app->getFileSelectionModel()->currentIndex());
   if (!FileProxyModel::getPathIfIndexOfDir(index).isNull()) {
-    m_app->fetchDirectory(index);
+    m_app->expandDirectory(index);
     return true;
   }
   return false;
 }
 
+/**
+ * Expand the file list.
+ */
+void ScriptInterface::expandFileList()
+{
+  m_app->requestExpandFileList();
+}
+
 /**
  * Apply the file name format.
  */
