@@ -59,14 +59,14 @@ public:
     /** Destructor. */
     ~DetailInfo();
 
-    bool valid;              /**< true if information valid */
-    bool vbr;                /**< true if variable bitrate */
     QString format;          /**< format description */
     ChannelMode channelMode; /**< channel mode */
     unsigned channels;       /**< number of channels > 0 */
     unsigned sampleRate;     /**< sample rate in Hz > 0 */
     unsigned bitrate;        /**< 0 < bitrate in kbps < 999 */
     unsigned long duration;  /**< duration in seconds > 0 */
+    bool valid;              /**< true if information valid */
+    bool vbr;                /**< true if variable bitrate */
 
     /**
      * Get string representation of detail information.
@@ -170,7 +170,7 @@ public:
    *         "" if the field does not exist,
    *         QString::null if the tags do not exist.
    */
-  virtual QString getTitleV1();
+  virtual QString getTitleV1() const;
 
   /**
    * Get ID3v1 artist.
@@ -179,7 +179,7 @@ public:
    *         "" if the field does not exist,
    *         QString::null if the tags do not exist.
    */
-  virtual QString getArtistV1();
+  virtual QString getArtistV1() const;
 
   /**
    * Get ID3v1 album.
@@ -188,7 +188,7 @@ public:
    *         "" if the field does not exist,
    *         QString::null if the tags do not exist.
    */
-  virtual QString getAlbumV1();
+  virtual QString getAlbumV1() const;
 
   /**
    * Get ID3v1 comment.
@@ -197,7 +197,7 @@ public:
    *         "" if the field does not exist,
    *         QString::null if the tags do not exist.
    */
-  virtual QString getCommentV1();
+  virtual QString getCommentV1() const;
 
   /**
    * Get ID3v1 year.
@@ -206,7 +206,7 @@ public:
    *         0 if the field does not exist,
    *         -1 if the tags do not exist.
    */
-  virtual int getYearV1();
+  virtual int getYearV1() const;
 
   /**
    * Get ID3v1 track.
@@ -215,7 +215,7 @@ public:
    *         0 if the field does not exist,
    *         -1 if the tags do not exist.
    */
-  virtual int getTrackNumV1();
+  virtual int getTrackNumV1() const;
 
   /**
    * Get ID3v1 genre.
@@ -224,7 +224,7 @@ public:
    *         "" if the field does not exist,
    *         QString::null if the tags do not exist.
    */
-  virtual QString getGenreV1();
+  virtual QString getGenreV1() const;
 
   /**
    * Remove ID3v1 frames.
@@ -304,7 +304,7 @@ public:
    *         "" if the field does not exist,
    *         QString::null if the tags do not exist.
    */
-  virtual QString getTitleV2() = 0;
+  virtual QString getTitleV2() const = 0;
 
   /**
    * Get ID3v2 artist.
@@ -313,7 +313,7 @@ public:
    *         "" if the field does not exist,
    *         QString::null if the tags do not exist.
    */
-  virtual QString getArtistV2() = 0;
+  virtual QString getArtistV2() const = 0;
 
   /**
    * Get ID3v2 album.
@@ -322,7 +322,7 @@ public:
    *         "" if the field does not exist,
    *         QString::null if the tags do not exist.
    */
-  virtual QString getAlbumV2() = 0;
+  virtual QString getAlbumV2() const = 0;
 
   /**
    * Get ID3v2 comment.
@@ -331,7 +331,7 @@ public:
    *         "" if the field does not exist,
    *         QString::null if the tags do not exist.
    */
-  virtual QString getCommentV2() = 0;
+  virtual QString getCommentV2() const = 0;
 
   /**
    * Get ID3v2 year.
@@ -340,7 +340,7 @@ public:
    *         0 if the field does not exist,
    *         -1 if the tags do not exist.
    */
-  virtual int getYearV2() = 0;
+  virtual int getYearV2() const = 0;
 
   /**
    * Get ID3v2 track.
@@ -349,7 +349,7 @@ public:
    *         "" if the field does not exist,
    *         QString::null if the tags do not exist.
    */
-  virtual QString getTrackV2() = 0;
+  virtual QString getTrackV2() const = 0;
 
   /**
    * Remove ID3v2 frames.
@@ -365,7 +365,7 @@ public:
    *         "" if the field does not exist,
    *         QString::null if the tags do not exist.
    */
-  virtual QString getGenreV2() = 0;
+  virtual QString getGenreV2() const = 0;
 
   /**
    * Set ID3v2 title.
@@ -832,16 +832,16 @@ private:
   QString m_newFilename;
   /** Index of file in model */
   QPersistentModelIndex m_index;
-  /** true if ID3v1 tags were changed */
-  bool m_changedV1;
   /** changed tag 1 frame types */
   quint64 m_changedFramesV1;
-  /** true if ID3v2 tags were changed */
-  bool m_changedV2;
   /** changed tag 2 frame types */
   quint64 m_changedFramesV2;
   /** Truncation flags. */
   quint64 m_truncation;
+  /** true if ID3v1 tags were changed */
+  bool m_changedV1;
+  /** true if ID3v2 tags were changed */
+  bool m_changedV2;
 };
 
 #endif // TAGGEDFILE_H
