@@ -46,6 +46,7 @@
 #include "iplatformtools.h"
 #include "timeeventmodel.h"
 #include "timeeventeditor.h"
+#include "pictureframe.h"
 
 /** QTextEdit with label above */
 class LabeledTextEdit : public QWidget {
@@ -1013,11 +1014,9 @@ EditFrameFieldsDialog::EditFrameFieldsDialog(IPlatformTools* platformTools,
   m_vlayout = new QVBoxLayout(this);
 
   QHBoxLayout* hlayout = new QHBoxLayout;
-  QSpacerItem* hspacer = new QSpacerItem(16, 0, QSizePolicy::Expanding,
-             QSizePolicy::Minimum);
-  QPushButton* okButton = new QPushButton(tr("&OK"), this);
-  QPushButton* cancelButton = new QPushButton(tr("&Cancel"), this);
-  hlayout->addItem(hspacer);
+  QPushButton* okButton = new QPushButton(tr("&OK"));
+  QPushButton* cancelButton = new QPushButton(tr("&Cancel"));
+  hlayout->addStretch();
   hlayout->addWidget(okButton);
   hlayout->addWidget(cancelButton);
   okButton->setAutoDefault(false);
@@ -1049,15 +1048,13 @@ void EditFrameFieldsDialog::setFrame(const Frame& frame,
   m_fields = frame.getFieldList();
 
   // Remove all items, keep the last item.
-  QLayoutItem* lastItem = 0;
-  while (QLayoutItem* item = m_vlayout->takeAt(0)) {
-    if (lastItem) {
-      if (QWidget* widget = lastItem->widget()) {
+  for (int i = m_vlayout->count() - 2; i >= 0; --i) {
+    if (QLayoutItem* item = m_vlayout->takeAt(i)) {
+      if (QWidget* widget = item->widget()) {
         delete widget;
       }
-      delete lastItem;
+      delete item;
     }
-    lastItem = item;
   }
 
   qDeleteAll(m_fieldcontrols);
@@ -1082,31 +1079,8 @@ void EditFrameFieldsDialog::setFrame(const Frame& frame,
           m_fieldcontrols.append(cbox);
         }
         else if (fld.m_id == Frame::Field::ID_PictureType) {
-          static const char* strlst[] = {
-            QT_TRANSLATE_NOOP("@default", "Other"),
-            QT_TRANSLATE_NOOP("@default", "32x32 pixels PNG file icon"),
-            QT_TRANSLATE_NOOP("@default", "Other file icon"),
-            QT_TRANSLATE_NOOP("@default", "Cover (front)"),
-            QT_TRANSLATE_NOOP("@default", "Cover (back)"),
-            QT_TRANSLATE_NOOP("@default", "Leaflet page"),
-            QT_TRANSLATE_NOOP("@default", "Media"),
-            QT_TRANSLATE_NOOP("@default", "Lead artist/lead performer/soloist"),
-            QT_TRANSLATE_NOOP("@default", "Artist/performer"),
-            QT_TRANSLATE_NOOP("@default", "Conductor"),
-            QT_TRANSLATE_NOOP("@default", "Band/Orchestra"),
-            QT_TRANSLATE_NOOP("@default", "Composer"),
-            QT_TRANSLATE_NOOP("@default", "Lyricist/text writer"),
-            QT_TRANSLATE_NOOP("@default", "Recording Location"),
-            QT_TRANSLATE_NOOP("@default", "During recording"),
-            QT_TRANSLATE_NOOP("@default", "During performance"),
-            QT_TRANSLATE_NOOP("@default", "Movie/video screen capture"),
-            QT_TRANSLATE_NOOP("@default", "A bright coloured fish"),
-            QT_TRANSLATE_NOOP("@default", "Illustration"),
-            QT_TRANSLATE_NOOP("@default", "Band/artist logotype"),
-            QT_TRANSLATE_NOOP("@default", "Publisher/Studio logotype"),
-            NULL
-          };
-          IntComboBoxControl* cbox = new IntComboBoxControl(fld, strlst);
+          IntComboBoxControl* cbox = new IntComboBoxControl(
+                fld, PictureFrame::getPictureTypeNames());
           m_fieldcontrols.append(cbox);
         }
         else if (fld.m_id == Frame::Field::ID_TimestampFormat) {
@@ -1193,13 +1167,9 @@ void EditFrameFieldsDialog::setFrame(const Frame& frame,
   }
 
   QListIterator<FieldControl*> it(m_fieldcontrols);
-  while (it.hasNext()) {
-    m_vlayout->addWidget(it.next()->createWidget(this));
-  }
-
-  // Restore the last item.
-  if (lastItem) {
-    m_vlayout->addItem(lastItem);
+  it.toBack();
+  while (it.hasPrevious()) {
+    m_vlayout->insertWidget(0, it.previous()->createWidget(this));
   }
 }
 
