@@ -32,8 +32,10 @@
 #include "frame.h"
 #include <QList>
 
+class QVBoxLayout;
 class TaggedFile;
 class IPlatformTools;
+class Kid3Application;
 
 /** Row of buttons to load, save and view binary data */
 class BinaryOpenSave : public QWidget {
@@ -118,8 +120,6 @@ class BinaryOpenSave : public QWidget {
   IPlatformTools* m_platformTools;
   /** Array with binary data */
   QByteArray m_byteArray;
-  /** true if m_byteArray changed */
-  bool m_isChanged;
   /** Label left of buttons */
   QLabel* m_label;
   /** From Clipboard button */
@@ -130,6 +130,8 @@ class BinaryOpenSave : public QWidget {
   QString m_defaultFile;
   /** Filter names */
   QString m_filter;
+  /** true if m_byteArray changed */
+  bool m_isChanged;
 };
 
 
@@ -144,7 +146,7 @@ public:
   /**
    * Destructor.
    */
-  virtual ~FieldControl() {}
+  virtual ~FieldControl();
 
   /**
    * Update field from data in field control.
@@ -170,20 +172,25 @@ public:
    * Constructor.
    *
    * @param platformTools platform tools
+   * @param app application context
    * @param parent     parent widget
-   * @param caption    caption
-   * @param frame      frame with fields to edit
-   * @param taggedFile file
    */
-  EditFrameFieldsDialog(IPlatformTools* platformTools, QWidget* parent,
-                        const QString& caption,
-                        const Frame& frame, const TaggedFile* taggedFile);
+  EditFrameFieldsDialog(IPlatformTools* platformTools, Kid3Application* app,
+                        QWidget* parent = 0);
 
   /**
    * Destructor.
    */
   virtual ~EditFrameFieldsDialog();
 
+  /**
+   * Set frame to edit.
+   *
+   * @param frame      frame with fields to edit
+   * @param taggedFile file
+   */
+  void setFrame(const Frame& frame, const TaggedFile* taggedFile);
+
   /**
    * Update fields and get edited fields.
    *
@@ -191,9 +198,21 @@ public:
    */
   const Frame::FieldList& getUpdatedFieldList();
 
+  /**
+   * Get value of frame for frames without a field list.
+   * First getUpdatedFieldList() has to be called, if the returned field list
+   * is empty, the frame value is available with this method.
+   *
+   * @return frame value.
+   */
+  QString getFrameValue() const;
+
 private:
+  QVBoxLayout* m_vlayout;
   IPlatformTools* m_platformTools;
+  Kid3Application* m_app;
   Frame::FieldList m_fields;
+  Frame::Field m_valueField;
   QList<FieldControl*> m_fieldcontrols;
 };
 
