@@ -47,13 +47,14 @@
 #include "batchimportdialog.h"
 #include "browsecoverartdialog.h"
 #include "exportdialog.h"
+#include "findreplacedialog.h"
+#include "tagsearcher.h"
 #include "numbertracksdialog.h"
 #include "filterdialog.h"
 #include "rendirdialog.h"
 #include "downloadclient.h"
 #include "downloaddialog.h"
 #include "playlistdialog.h"
-#include "editframedialog.h"
 #include "editframefieldsdialog.h"
 #include "fileproxymodel.h"
 #include "fileproxymodeliterator.h"
@@ -88,19 +89,22 @@
  *
  * @param mainWin main window widget
  * @param platformTools platform specific tools
+ * @param app application context
  */
 BaseMainWindowImpl::BaseMainWindowImpl(QMainWindow* mainWin,
-                                       IPlatformTools* platformTools) :
+                                       IPlatformTools* platformTools,
+                                       Kid3Application* app) :
   m_platformTools(platformTools), m_w(mainWin), m_self(0),
-  m_app(new Kid3Application(m_platformTools, this)),
+  m_app(app),
   m_importDialog(0), m_batchImportDialog(0), m_browseCoverArtDialog(0),
-  m_exportDialog(0), m_renDirDialog(0),
+  m_exportDialog(0), m_findReplaceDialog(0), m_renDirDialog(0),
   m_numberTracksDialog(0), m_filterDialog(0),
   m_downloadDialog(new DownloadDialog(m_w, tr("Download"))),
-  m_playlistDialog(0), m_progressDialog(0)
+  m_playlistDialog(0), m_progressDialog(0), m_editFrameDialog(0),
 #if defined HAVE_PHONON || QT_VERSION >= 0x050000
-  , m_playToolBar(0)
+  m_playToolBar(0),
 #endif
+  m_editFrameTaggedFile(0), m_findReplaceActive(false)
 {
   ContextHelp::init(m_platformTools);
 
@@ -128,6 +132,10 @@ BaseMainWindowImpl::BaseMainWindowImpl(QMainWindow* mainWin,
           this, SLOT(updateModificationState()));
   connect(m_app, SIGNAL(confirmedOpenDirectoryRequested(QStringList)),
           this, SLOT(confirmedOpenDirectory(QStringList)));
+  connect(m_app, SIGNAL(toggleExpandedRequested(QModelIndex)),
+          this, SLOT(toggleExpanded(QModelIndex)));
+  connect(m_app, SIGNAL(expandFileListRequested()),
+          this, SLOT(expandFileList()));
   connect(m_app,
     SIGNAL(directoryOpened(QPersistentModelIndex,QList<QPersistentModelIndex>)),
     this, SLOT(onDirectoryOpened()));
@@ -621,6 +629,97 @@ void BaseMainWindowImpl::applyChangedConfiguration()
   }
 }
 
+/**
+ * Find and replace in tags of files.
+ * @param findOnly true to display only find part of dialog
+ */
+void BaseMainWindowImpl::findReplace(bool findOnly)
+{
+  TagSearcher* tagSearcher = m_app->getTagSearcher();
+  if (!m_findReplaceDialog) {
+    m_findReplaceDialog = new FindReplaceDialog(m_w);
+    connect(m_findReplaceDialog, SIGNAL(findRequested(TagSearcher::Parameters)),
+            m_app, SLOT(findText(TagSearcher::Parameters)));
+    connect(m_findReplaceDialog,
+            SIGNAL(replaceRequested(TagSearcher::Parameters)),
+            m_app, SLOT(replaceText(TagSearcher::Parameters)));
+    connect(m_findReplaceDialog,
+            SIGNAL(replaceAllRequested(TagSearcher::Parameters)),
+            m_app, SLOT(replaceAll(TagSearcher::Parameters)));
+    connect(m_findReplaceDialog, SIGNAL(finished(int)),
+            this, SLOT(deactivateFindReplace()));
+    connect(tagSearcher, SIGNAL(progress(QString)),
+            m_findReplaceDialog, SLOT(showProgress(QString)));
+  }
+  m_findReplaceDialog->init(findOnly);
+  m_findReplaceDialog->show();
+  if (!m_findReplaceActive) {
+    QModelIndexList selItems(m_app->getFileSelectionModel()->selectedRows());
+    if (selItems.size() == 1) {
+      tagSearcher->setStartIndex(selItems.first());
+    }
+    connect(tagSearcher, SIGNAL(textFound()),
+            this, SLOT(showFoundText()));
+    connect(tagSearcher, SIGNAL(textReplaced()),
+            this, SLOT(updateReplacedText()));
+    m_findReplaceActive = true;
+  }
+}
+
+/**
+ * Deactivate showing of find replace results.
+ */
+void BaseMainWindowImpl::deactivateFindReplace()
+{
+  if (m_findReplaceActive) {
+    TagSearcher* tagSearcher = m_app->getTagSearcher();
+    tagSearcher->abort();
+    disconnect(tagSearcher, SIGNAL(textFound()),
+               this, SLOT(showFoundText()));
+    disconnect(tagSearcher, SIGNAL(textReplaced()),
+               this, SLOT(updateReplacedText()));
+    m_findReplaceActive = false;
+  }
+}
+
+/**
+ * Ensure that found text is made visible in the GUI.
+ */
+void BaseMainWindowImpl::showFoundText()
+{
+  const TagSearcher::Position& pos = m_app->getTagSearcher()->getPosition();
+  if (pos.isValid()) {
+    m_app->getFileSelectionModel()->setCurrentIndex(pos.getFileIndex(),
+        QItemSelectionModel::ClearAndSelect | QItemSelectionModel::Rows);
+    switch (pos.getPart()) {
+    case TagSearcher::Position::FileName:
+      m_form->setFilenameSelection(pos.getMatchedPos(), pos.getMatchedLength());
+      break;
+    case TagSearcher::Position::Tag1:
+      m_form->frameTableV1()->setValueSelection(
+            pos.getFrameIndex(), pos.getMatchedPos(), pos.getMatchedLength());
+      break;
+    case TagSearcher::Position::Tag2:
+      m_form->frameTableV2()->setValueSelection(
+            pos.getFrameIndex(), pos.getMatchedPos(), pos.getMatchedLength());
+      break;
+    }
+  }
+}
+
+/**
+ * Update GUI controls after text has been replaced.
+ */
+void BaseMainWindowImpl::updateReplacedText()
+{
+  const TagSearcher::Position& pos = m_app->getTagSearcher()->getPosition();
+  if (pos.isValid()) {
+    m_app->getFileSelectionModel()->setCurrentIndex(pos.getFileIndex(),
+        QItemSelectionModel::ClearAndSelect | QItemSelectionModel::Rows);
+    updateGuiControls();
+  }
+}
+
 /**
  * Rename directory.
  */
@@ -900,22 +999,40 @@ bool BaseMainWindowImpl::selectFrame(Frame* frame, const TaggedFile* taggedFile)
   return ok;
 }
 
+/**
+ * Return object which emits frameEdited() signal.
+ *
+ * @return object which emits frameEdited() when dialog is closed, its
+ * parameter is the edited frame if the dialog is accepted.
+ */
+QObject* BaseMainWindowImpl::frameEditedEmitter()
+{
+  return this;
+}
+
 /**
  * Create dialog to edit a frame and update the fields
  * if Ok is returned.
+ * frameEdited() is emitted when the edit dialog is closed with the edited
+ * frame as a parameter if it was accepted.
  *
  * @param frame frame to edit
  * @param taggedFile tagged file where frame has to be set
- *
- * @return true if Ok selected in dialog.
  */
-bool BaseMainWindowImpl::editFrameOfTaggedFile(Frame* frame, TaggedFile* taggedFile)
+void BaseMainWindowImpl::editFrameOfTaggedFile(const Frame* frame,
+                                               TaggedFile* taggedFile)
 {
-  if (!frame || !taggedFile)
-    return false;
+  if (!frame || !taggedFile) {
+    emit frameEdited(0);
+    return;
+  }
 
-  bool result = true;
-  QString name(frame->getInternalName());
+  m_editFrame = *frame;
+  m_editFrameTaggedFile = taggedFile;
+  QString name(m_editFrame.getInternalName());
+  if (name.isEmpty()) {
+    name = m_editFrame.getName();
+  }
   if (!name.isEmpty()) {
     int nlPos = name.indexOf(QLatin1Char('\n'));
     if (nlPos > 0) {
@@ -925,29 +1042,38 @@ bool BaseMainWindowImpl::editFrameOfTaggedFile(Frame* frame, TaggedFile* taggedF
     }
     name = QCoreApplication::translate("@default", name.toLatin1().data());
   }
-  if (frame->getFieldList().empty()) {
-    EditFrameDialog* dialog =
-      new EditFrameDialog(m_w, name, frame->getValue());
-    result = dialog && dialog->exec() == QDialog::Accepted;
-    if (result) {
-      frame->setValue(dialog->getText());
-    }
-  } else {
-    EditFrameFieldsDialog* dialog =
-      new EditFrameFieldsDialog(m_platformTools,
-                                m_w, name, *frame, taggedFile);
-    result = dialog && dialog->exec() == QDialog::Accepted;
-    if (result) {
-      frame->setFieldList(dialog->getUpdatedFieldList());
-      frame->setValueFromFieldList();
+  if (!m_editFrameDialog) {
+    m_editFrameDialog = new EditFrameFieldsDialog(m_platformTools, m_app, m_w);
+    connect(m_editFrameDialog, SIGNAL(finished(int)),
+            this, SLOT(onEditFrameDialogFinished(int)));
+  }
+  m_editFrameDialog->setWindowTitle(name);
+  m_editFrameDialog->setFrame(m_editFrame, m_editFrameTaggedFile);
+  m_editFrameDialog->show();
+}
+
+/**
+ * Called when the edit fram dialog is finished.
+ * @param result dialog result
+ */
+void BaseMainWindowImpl::onEditFrameDialogFinished(int result)
+{
+  if (EditFrameFieldsDialog* dialog =
+      qobject_cast<EditFrameFieldsDialog*>(sender())) {
+    if (result == QDialog::Accepted) {
+      const Frame::FieldList& fields = dialog->getUpdatedFieldList();
+      if (fields.isEmpty()) {
+        m_editFrame.setValue(dialog->getFrameValue());
+      } else {
+        m_editFrame.setFieldList(fields);
+        m_editFrame.setValueFromFieldList();
+      }
+      if (m_editFrameTaggedFile->setFrameV2(m_editFrame)) {
+        m_editFrameTaggedFile->markTag2Changed(m_editFrame.getType());
+      }
     }
   }
-  if (result) {
-    if (taggedFile->setFrameV2(*frame)) {
-      taggedFile->markTag2Changed(frame->getType());
-    }
-  }
-  return result;
+  emit frameEdited(result == QDialog::Accepted ? &m_editFrame : 0);
 }
 
 /**
@@ -962,7 +1088,7 @@ void BaseMainWindowImpl::renameFile()
     return;
 
   QList<QPersistentModelIndex> selItems;
-  foreach (const QModelIndex& index, selectModel->selectedIndexes())
+  foreach (const QModelIndex& index, selectModel->selectedRows())
     selItems.append(index);
   foreach (const QPersistentModelIndex& index, selItems) {
     TaggedFile* taggedFile = FileProxyModel::getTaggedFileOfIndex(index);
@@ -1026,13 +1152,13 @@ void BaseMainWindowImpl::deleteFile()
 
   QStringList files;
   QList<QPersistentModelIndex> selItems;
-  foreach (const QModelIndex& index, selectModel->selectedIndexes())
+  foreach (const QModelIndex& index, selectModel->selectedRows())
     selItems.append(index);
   foreach (const QPersistentModelIndex& index, selItems) {
     files.append(model->filePath(index));
   }
 
-  unsigned numFiles = files.size();
+  const int numFiles = files.size();
   if (numFiles > 0) {
     if (m_platformTools->warningContinueCancelList(
           m_w,
@@ -1074,6 +1200,16 @@ void BaseMainWindowImpl::deleteFile()
   }
 }
 
+/**
+ * Toggle expanded state of directory in the file list.
+ * @param index index of directory
+ */
+void BaseMainWindowImpl::toggleExpanded(const QModelIndex& index)
+{
+  QTreeView* fileList = m_form->getFileList();
+  fileList->setExpanded(index, !fileList->isExpanded(index));
+}
+
 /**
  * Expand the file list.
  */
@@ -1132,11 +1268,14 @@ void BaseMainWindowImpl::expandNextDirectory(const QPersistentModelIndex& index)
 /**
  * Constructor.
  *
+ * @param mainWin main window
  * @param platformTools platform specific tools
+ * @param app application context
  */
 BaseMainWindow::BaseMainWindow(QMainWindow* mainWin,
-                               IPlatformTools* platformTools) :
-  m_impl(new BaseMainWindowImpl(mainWin, platformTools))
+                               IPlatformTools* platformTools,
+                               Kid3Application* app) :
+  m_impl(new BaseMainWindowImpl(mainWin, platformTools, app))
 {
   m_impl->setBackPointer(this);
 }
@@ -1171,18 +1310,30 @@ bool BaseMainWindow::selectFrame(Frame* frame, const TaggedFile* taggedFile)
   return m_impl->selectFrame(frame, taggedFile);
 }
 
+/**
+ * Return object which emits frameEdited() signal.
+ *
+ * @return object which emits frameEdited() when dialog is closed, its
+ * parameter is the edited frame if the dialog is accepted.
+ */
+QObject* BaseMainWindow::frameEditedEmitter()
+{
+  return m_impl;
+}
+
 /**
  * Create dialog to edit a frame and update the fields
  * if Ok is returned.
+ * frameEdited() is emitted when the edit dialog is closed with the edited
+ * frame as a parameter if it was accepted.
  *
  * @param frame frame to edit
  * @param taggedFile tagged file where frame has to be set
- *
- * @return true if Ok selected in dialog.
  */
-bool BaseMainWindow::editFrameOfTaggedFile(Frame* frame, TaggedFile* taggedFile)
+void BaseMainWindow::editFrameOfTaggedFile(const Frame* frame,
+                                           TaggedFile* taggedFile)
 {
-  return m_impl->editFrameOfTaggedFile(frame, taggedFile);
+  m_impl->editFrameOfTaggedFile(frame, taggedFile);
 }
 
 #if defined HAVE_PHONON || QT_VERSION >= 0x050000
