@@ -6,7 +6,7 @@
  * \author Urs Fleisch
  * \date 9 Jan 2003
  *
- * Copyright (C) 2003-2013  Urs Fleisch
+ * Copyright (C) 2003-2014  Urs Fleisch
  *
  * This file is part of Kid3.
  *
@@ -31,6 +31,7 @@
 #include <QUrl>
 #include <QMenu>
 #include <QHeaderView>
+#include <QDesktopServices>
 #include "fileproxymodel.h"
 #include "modeliterator.h"
 #include "taggedfile.h"
@@ -46,11 +47,11 @@
  * @param mainWin main window
  */
 FileList::FileList(QWidget* parent, BaseMainWindowImpl* mainWin) :
-  QTreeView(parent), m_process(0), m_mainWin(mainWin)
+  ConfigurableTreeView(parent), m_process(0), m_mainWin(mainWin),
+  m_renameAction(0), m_deleteAction(0)
 {
   setObjectName(QLatin1String("FileList"));
   setSelectionMode(ExtendedSelection);
-  setSortingEnabled(false);
   setContextMenuPolicy(Qt::CustomContextMenu);
   connect(this, SIGNAL(customContextMenuRequested(QPoint)),
       this, SLOT(customContextMenu(QPoint)));
@@ -58,7 +59,6 @@ FileList::FileList(QWidget* parent, BaseMainWindowImpl* mainWin) :
   connect(this, SIGNAL(doubleClicked(QModelIndex)),
           this, SLOT(playIfTaggedFile(QModelIndex)));
 #endif
-  header()->hide();
 }
 
 /**
@@ -96,7 +96,8 @@ bool FileList::readDir(const QPersistentModelIndex& dirIndex,
       selModel->clearSelection();
       if (!fileIndexes.isEmpty()) {
         foreach (const QPersistentModelIndex& fileIndex, fileIndexes) {
-          selModel->select(fileIndex, QItemSelectionModel::Select);
+          selModel->select(fileIndex,
+              QItemSelectionModel::Select | QItemSelectionModel::Rows);
           scrollTo(fileIndex);
         }
         selModel->setCurrentIndex(fileIndexes.first(),
@@ -120,7 +121,7 @@ void FileList::updateCurrentSelection()
   if (!selectionModel())
     return;
   m_currentSelection.clear();
-  foreach (const QModelIndex& index, selectionModel()->selectedIndexes()) {
+  foreach (const QModelIndex& index, selectionModel()->selectedRows()) {
     m_currentSelection.append(QPersistentModelIndex(index));
   }
 }
@@ -137,11 +138,18 @@ void FileList::contextMenu(const QModelIndex& index, const QPoint& pos)
     QMenu menu(this);
     menu.addAction(tr("&Expand all"), m_mainWin, SLOT(expandFileList()));
     menu.addAction(tr("&Collapse all"), this, SLOT(collapseAll()));
-    menu.addAction(tr("&Rename"), m_mainWin, SLOT(renameFile()));
-    menu.addAction(tr("&Move to Trash"), m_mainWin, SLOT(deleteFile()));
+    if (m_renameAction) {
+      menu.addAction(m_renameAction);
+    }
+    if (m_deleteAction) {
+      menu.addAction(m_deleteAction);
+    }
 #if defined HAVE_PHONON || QT_VERSION >= 0x050000
     menu.addAction(tr("&Play"), m_mainWin, SLOT(slotPlayAudio()));
 #endif
+    menu.addAction(tr("&Open"), this, SLOT(openFile()));
+    menu.addAction(tr("Open Containing &Folder"),
+                   this, SLOT(openContainingFolder()));
     int id = 0;
     for (QList<UserActionsConfig::MenuCommand>::const_iterator
            it = UserActionsConfig::instance().m_contextMenuCommands.begin();
@@ -185,7 +193,7 @@ QStringList FileList::formatStringList(const QStringList& format)
   QStringList files;
   TaggedFile* firstSelectedFile = 0;
   QModelIndexList selItems(selectionModel()
-       ? selectionModel()->selectedIndexes() : QModelIndexList());
+       ? selectionModel()->selectedRows() : QModelIndexList());
   foreach (const QModelIndex& index, selItems) {
     if (TaggedFile* taggedFile = FileProxyModel::getTaggedFileOfIndex(index)) {
       if (!firstSelectedFile) {
@@ -343,3 +351,69 @@ void FileList::playIfTaggedFile(const QModelIndex& index)
   }
 }
 #endif
+
+/**
+ * Set rename action.
+ * @param action rename action
+ */
+void FileList::setRenameAction(QAction* action)
+{
+  if (m_renameAction) {
+    removeAction(m_renameAction);
+  }
+  m_renameAction = action;
+  if (m_renameAction) {
+    addAction(m_renameAction);
+  }
+}
+
+/**
+ * Set delete action.
+ * @param action delete action
+ */
+void FileList::setDeleteAction(QAction* action)
+{
+  if (m_deleteAction) {
+    removeAction(m_deleteAction);
+  }
+  m_deleteAction = action;
+  if (m_deleteAction) {
+    addAction(m_deleteAction);
+  }
+}
+
+/**
+ * Open with standard application.
+ */
+void FileList::openFile()
+{
+  if (QItemSelectionModel* selModel = selectionModel()) {
+    if (const FileProxyModel* fsModel =
+        qobject_cast<const FileProxyModel*>(selModel->model())) {
+      foreach (const QModelIndex& index, selModel->selectedRows()) {
+        QDesktopServices::openUrl(
+              QUrl::fromLocalFile(fsModel->filePath(index)));
+      }
+    }
+  }
+}
+
+/**
+ * Open containing folder.
+ */
+void FileList::openContainingFolder()
+{
+  if (QItemSelectionModel* selModel = selectionModel()) {
+    QModelIndexList indexes = selModel->selectedRows();
+    if (!indexes.isEmpty()) {
+      const FileProxyModel* fsModel;
+      QModelIndex index = indexes.first().parent();
+      if (index.isValid() &&
+          (fsModel = qobject_cast<const FileProxyModel*>(index.model())) != 0 &&
+          fsModel->isDir(index)) {
+        QDesktopServices::openUrl(
+              QUrl::fromLocalFile(fsModel->filePath(index)));
+      }
+    }
+  }
+}
