@@ -564,7 +564,11 @@ void M4aFile::readTags(bool force)
         }
       }
 #endif
-      MP4Close(handle);
+      MP4Close(handle
+#if MPEG4IP_MAJOR_MINOR_VERSION >= 0x0200
+               , MP4_CLOSE_DO_NOT_COMPUTE_BITRATE
+#endif
+               );
     }
   }
 
@@ -866,7 +870,11 @@ bool M4aFile::writeTags(bool force, bool* renamed, bool preserve)
       MP4TagsFree(tags);
 #endif
 
-      MP4Close(handle);
+      MP4Close(handle
+#if MPEG4IP_MAJOR_MINOR_VERSION >= 0x0200
+               , MP4_CLOSE_DO_NOT_COMPUTE_BITRATE
+#endif
+               );
       if (ok) {
         // without this, old tags stay in the file marked as free
         MP4Optimize(fn);
@@ -978,7 +986,7 @@ void M4aFile::setTextField(const QString& name, const QString& value,
  *         "" if the field does not exist,
  *         QString::null if the tags do not exist.
  */
-QString M4aFile::getTitleV2()
+QString M4aFile::getTitleV2() const
 {
   return getTextField(QLatin1String("\251nam"));
 }
@@ -990,7 +998,7 @@ QString M4aFile::getTitleV2()
  *         "" if the field does not exist,
  *         QString::null if the tags do not exist.
  */
-QString M4aFile::getArtistV2()
+QString M4aFile::getArtistV2() const
 {
   return getTextField(QLatin1String("\251ART"));
 }
@@ -1002,7 +1010,7 @@ QString M4aFile::getArtistV2()
  *         "" if the field does not exist,
  *         QString::null if the tags do not exist.
  */
-QString M4aFile::getAlbumV2()
+QString M4aFile::getAlbumV2() const
 {
   return getTextField(QLatin1String("\251alb"));
 }
@@ -1014,7 +1022,7 @@ QString M4aFile::getAlbumV2()
  *         "" if the field does not exist,
  *         QString::null if the tags do not exist.
  */
-QString M4aFile::getCommentV2()
+QString M4aFile::getCommentV2() const
 {
   return getTextField(QLatin1String("\251cmt"));
 }
@@ -1026,7 +1034,7 @@ QString M4aFile::getCommentV2()
  *         0 if the field does not exist,
  *         -1 if the tags do not exist.
  */
-int M4aFile::getYearV2()
+int M4aFile::getYearV2() const
 {
   QString str(getTextField(QLatin1String("\251day")));
   if (!str.isNull()) {
@@ -1042,7 +1050,7 @@ int M4aFile::getYearV2()
  *         "" if the field does not exist,
  *         QString::null if the tags do not exist.
  */
-QString M4aFile::getTrackV2()
+QString M4aFile::getTrackV2() const
 {
   return getTextField(QLatin1String("trkn"));
 }
@@ -1054,7 +1062,7 @@ QString M4aFile::getTrackV2()
  *         "" if the field does not exist,
  *         QString::null if the tags do not exist.
  */
-QString M4aFile::getGenreV2()
+QString M4aFile::getGenreV2() const
 {
   QString str(getTextField(QLatin1String("\251gen")));
   if (str.isEmpty()) {
