@@ -88,7 +88,7 @@ public:
    *         "" if the field does not exist,
    *         QString::null if the tags do not exist.
    */
-  virtual QString getTitleV2();
+  virtual QString getTitleV2() const;
 
   /**
    * Get ID3v2 artist.
@@ -97,7 +97,7 @@ public:
    *         "" if the field does not exist,
    *         QString::null if the tags do not exist.
    */
-  virtual QString getArtistV2();
+  virtual QString getArtistV2() const;
 
   /**
    * Get ID3v2 album.
@@ -106,7 +106,7 @@ public:
    *         "" if the field does not exist,
    *         QString::null if the tags do not exist.
    */
-  virtual QString getAlbumV2();
+  virtual QString getAlbumV2() const;
 
   /**
    * Get ID3v2 comment.
@@ -115,7 +115,7 @@ public:
    *         "" if the field does not exist,
    *         QString::null if the tags do not exist.
    */
-  virtual QString getCommentV2();
+  virtual QString getCommentV2() const;
 
   /**
    * Get ID3v2 year.
@@ -124,7 +124,7 @@ public:
    *         0 if the field does not exist,
    *         -1 if the tags do not exist.
    */
-  virtual int getYearV2();
+  virtual int getYearV2() const;
 
   /**
    * Get ID3v2 track.
@@ -133,7 +133,7 @@ public:
    *         "" if the field does not exist,
    *         QString::null if the tags do not exist.
    */
-  virtual QString getTrackV2();
+  virtual QString getTrackV2() const;
 
   /**
    * Get ID3v2 genre as text.
@@ -142,7 +142,7 @@ public:
    *         "" if the field does not exist,
    *         QString::null if the tags do not exist.
    */
-  virtual QString getGenreV2();
+  virtual QString getGenreV2() const;
 
   /**
    * Set ID3v2 title.
