@@ -96,7 +96,7 @@ public:
    *         "" if the field does not exist,
    *         QString::null if the tags do not exist.
    */
-  virtual QString getTitleV2();
+  virtual QString getTitleV2() const;
 
   /**
    * Get ID3v2 artist.
@@ -105,7 +105,7 @@ public:
    *         "" if the field does not exist,
    *         QString::null if the tags do not exist.
    */
-  virtual QString getArtistV2();
+  virtual QString getArtistV2() const;
 
   /**
    * Get ID3v2 album.
@@ -114,7 +114,7 @@ public:
    *         "" if the field does not exist,
    *         QString::null if the tags do not exist.
    */
-  virtual QString getAlbumV2();
+  virtual QString getAlbumV2() const;
 
   /**
    * Get ID3v2 comment.
@@ -123,7 +123,7 @@ public:
    *         "" if the field does not exist,
    *         QString::null if the tags do not exist.
    */
-  virtual QString getCommentV2();
+  virtual QString getCommentV2() const;
 
   /**
    * Get ID3v2 year.
@@ -132,7 +132,7 @@ public:
    *         0 if the field does not exist,
    *         -1 if the tags do not exist.
    */
-  virtual int getYearV2();
+  virtual int getYearV2() const;
 
   /**
    * Get ID3v2 track.
@@ -141,7 +141,7 @@ public:
    *         "" if the field does not exist,
    *         QString::null if the tags do not exist.
    */
-  virtual QString getTrackV2();
+  virtual QString getTrackV2() const;
 
   /**
    * Get ID3v2 genre as text.
@@ -150,7 +150,7 @@ public:
    *         "" if the field does not exist,
    *         QString::null if the tags do not exist.
    */
-  virtual QString getGenreV2();
+  virtual QString getGenreV2() const;
 
   /**
    * Set ID3v2 title.
@@ -362,11 +362,6 @@ protected:
   void setTextField(const QString& name, const QString& value,
                     Frame::Type type);
 
-  /** Comments of this file. */
-  CommentList m_comments;
-  /** true if file has been read. */
-  bool m_fileRead;
-
 private:
   OggFile(const OggFile&);
   OggFile& operator=(const OggFile&);
@@ -375,8 +370,8 @@ private:
   /** Information about Ogg/Vorbis file. */
   struct FileInfo {
     /** Constructor. */
-    FileInfo() : valid(false), version(0), channels(0),
-      sampleRate(0), bitrate(0), duration(0) {}
+    FileInfo() : version(0), channels(0),
+      sampleRate(0), bitrate(0), duration(0), valid(false) {}
 
     /**
      * Read information about an Ogg/Vorbis file.
@@ -385,17 +380,23 @@ private:
      */
     bool read(const QString& fn);
 
-    bool valid;      /**< true if read() was successful */
     int version;     /**< vorbis encoder version */
     int channels;    /**< number of channels */
     long sampleRate; /**< sample rate in Hz */
     long bitrate;    /**< bitrate in bits/s */
     long duration;   /**< duration in seconds */
+    bool valid;      /**< true if read() was successful */
   };
 
   /** Info about file. */
   FileInfo m_fileInfo;
 #endif // HAVE_VORBIS
+
+protected:
+  /** Comments of this file. */
+  CommentList m_comments;
+  /** true if file has been read. */
+  bool m_fileRead;
 };
 
 #endif // OGGFILE_H
