@@ -32,10 +32,10 @@
 #include <QtGlobal>
 #include "taggedfile.h"
 #include "tagconfig.h"
-#include <taglib/taglib.h>
-#include <taglib/fileref.h>
-#include <taglib/tag.h>
-#include <taglib/id3v2frame.h>
+#include <taglib.h>
+#include <fileref.h>
+#include <tag.h>
+#include <id3v2frame.h>
 
 /** TagLib version in with 8 bits for major, minor and patch version. */
 #define TAGLIB_VERSION (((TAGLIB_MAJOR_VERSION) << 16) + \
@@ -51,6 +51,13 @@
 
 class QTextCodec;
 
+#if TAGLIB_VERSION >= 0x010600 && defined TAGLIB_WITH_MP4
+  namespace TagLib {
+    namespace MP4 {
+      class Tag;
+    }
+  }
+#endif
 
 /** List box item containing tagged file. */
 class TagLibFile : public TaggedFile {
@@ -157,7 +164,7 @@ public:
    *         "" if the field does not exist,
    *         QString::null if the tags do not exist.
    */
-  virtual QString getTitleV1();
+  virtual QString getTitleV1() const;
 
   /**
    * Get ID3v1 artist.
@@ -166,7 +173,7 @@ public:
    *         "" if the field does not exist,
    *         QString::null if the tags do not exist.
    */
-  virtual QString getArtistV1();
+  virtual QString getArtistV1() const;
 
   /**
    * Get ID3v1 album.
@@ -175,7 +182,7 @@ public:
    *         "" if the field does not exist,
    *         QString::null if the tags do not exist.
    */
-  virtual QString getAlbumV1();
+  virtual QString getAlbumV1() const;
 
   /**
    * Get ID3v1 comment.
@@ -184,7 +191,7 @@ public:
    *         "" if the field does not exist,
    *         QString::null if the tags do not exist.
    */
-  virtual QString getCommentV1();
+  virtual QString getCommentV1() const;
 
   /**
    * Get ID3v1 year.
@@ -193,7 +200,7 @@ public:
    *         0 if the field does not exist,
    *         -1 if the tags do not exist.
    */
-  virtual int getYearV1();
+  virtual int getYearV1() const;
 
   /**
    * Get ID3v1 track.
@@ -202,7 +209,7 @@ public:
    *         0 if the field does not exist,
    *         -1 if the tags do not exist.
    */
-  virtual int getTrackNumV1();
+  virtual int getTrackNumV1() const;
 
   /**
    * Get ID3v1 genre.
@@ -211,7 +218,7 @@ public:
    *         "" if the field does not exist,
    *         QString::null if the tags do not exist.
    */
-  virtual QString getGenreV1();
+  virtual QString getGenreV1() const;
 
   /**
    * Get ID3v2 title.
@@ -220,7 +227,7 @@ public:
    *         "" if the field does not exist,
    *         QString::null if the tags do not exist.
    */
-  virtual QString getTitleV2();
+  virtual QString getTitleV2() const;
 
   /**
    * Get ID3v2 artist.
@@ -229,7 +236,7 @@ public:
    *         "" if the field does not exist,
    *         QString::null if the tags do not exist.
    */
-  virtual QString getArtistV2();
+  virtual QString getArtistV2() const;
 
   /**
    * Get ID3v2 album.
@@ -238,7 +245,7 @@ public:
    *         "" if the field does not exist,
    *         QString::null if the tags do not exist.
    */
-  virtual QString getAlbumV2();
+  virtual QString getAlbumV2() const;
 
   /**
    * Get ID3v2 comment.
@@ -247,7 +254,7 @@ public:
    *         "" if the field does not exist,
    *         QString::null if the tags do not exist.
    */
-  virtual QString getCommentV2();
+  virtual QString getCommentV2() const;
 
   /**
    * Get ID3v2 year.
@@ -256,7 +263,7 @@ public:
    *         0 if the field does not exist,
    *         -1 if the tags do not exist.
    */
-  virtual int getYearV2();
+  virtual int getYearV2() const;
 
   /**
    * Get ID3v2 track.
@@ -265,7 +272,7 @@ public:
    *         "" if the field does not exist,
    *         QString::null if the tags do not exist.
    */
-  virtual QString getTrackV2();
+  virtual QString getTrackV2() const;
 
   /**
    * Get ID3v2 genre as text.
@@ -274,7 +281,7 @@ public:
    *         "" if the field does not exist,
    *         QString::null if the tags do not exist.
    */
-  virtual QString getGenreV2();
+  virtual QString getGenreV2() const;
 
   /**
    * Set ID3v1 title.
@@ -553,7 +560,7 @@ private:
    *
    * @param force true to force reopening of file even if it is already open
    */
-  void makeFileOpen(bool force = false);
+  void makeFileOpen(bool force = false) const;
 
   /**
    * Create m_tagV1 if it does not already exist so that it can be set.
@@ -583,6 +590,15 @@ private:
   QString getTrackerName() const;
 #endif
 
+#if TAGLIB_VERSION >= 0x010600 && defined TAGLIB_WITH_MP4
+  /**
+   * Set a frame in an MP4 tag.
+   * @param frame frame to set
+   * @param mp4Tag MP4 tag
+   */
+  void setMp4Frame(const Frame& frame, TagLib::MP4::Tag* mp4Tag);
+#endif
+
   /**
    * Get the format of a tag.
    *
@@ -631,13 +647,8 @@ private:
   int m_id3v2Version;        /**< 3 for ID3v2.3, 4 for ID3v2.4, 0 if none */
 #endif
   int m_activatedFeatures;   /**< TF_ID3v23, TF_ID3v24, or 0 */
-  bool m_fileRead;           /**< true if file has been read */
 
   /* Cached information updated in readTags() */
-  bool m_tagInformationRead;
-  bool m_hasTagV1;
-  bool m_hasTagV2;
-  bool m_isTagV1Supported;
   unsigned m_duration;
   TagType m_tagTypeV1;
   TagType m_tagTypeV2;
@@ -660,6 +671,13 @@ private:
   Pictures m_pictures;
 #endif
 
+  bool m_tagInformationRead;
+  bool m_hasTagV1;
+  bool m_hasTagV2;
+  bool m_isTagV1Supported;
+
+  bool m_fileRead;           /**< true if file has been read */
+
   /** default text encoding */
   static TagLib::String::Type s_defaultTextEncoding;
 
